@@ -40,11 +40,12 @@
 #include "EnableWarnings.h"
 
 struct omxStateSpaceExpectation : omxExpectation {
+	typedef omxExpectation super;
 	omxMatrix *cov, *means;
 	omxMatrix *A, *B, *C, *D, *Q, *R, *t; // State Space model Matrices
 	omxMatrix *r, *s, *u, *x, *y, *z; // Data and place holder vectors
 	omxMatrix *K, *P, *S, *Y, *Z; // Behind the scenes state space matrices (P, S, and K) and place holder matrices
-	omxMatrix *x0, *P0; // Placeholders for initial state and initial mxThrow cov
+	omxMatrix *x0, *P0; // Placeholders for initial state and initial cov
 	omxMatrix *det; // Determinant of expected covariance matrix S
 	omxMatrix *smallC, *smallD, *smallr, *smallR, *smallK, *smallS, *smallY; //aliases of C, D, r, R, K, and S for missing data handling
 	omxMatrix *covInfo; //info from Cholesky decomp of small expected cov (smallS) to be passed to FIML single iteration
@@ -60,6 +61,7 @@ struct omxStateSpaceExpectation : omxExpectation {
 	Eigen::MatrixXd PSI;
 	Eigen::MatrixXd eigenPreX;
 	
+	omxStateSpaceExpectation(omxState *st, int num) : super(st, num) {}
 	virtual ~omxStateSpaceExpectation();
 	virtual void init();
 	virtual omxMatrix *getComponent(const char*);
@@ -837,7 +839,8 @@ void omxRauchTungStriebelSmooth(omxStateSpaceExpectation* ose) {
 }
 
 
-omxExpectation *omxInitStateSpaceExpectation() { return new omxStateSpaceExpectation; }
+omxExpectation *omxInitStateSpaceExpectation(omxState *st, int num)
+{ return new omxStateSpaceExpectation(st, num); }
 
 void omxStateSpaceExpectation::init()
 {
